==> hoteldruid-mod-bg_2.2.0-1.zip: bg/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Въведете нова резервация"; break;
case "Cliente titolare":  			$messaggio = "Титулярен клиент"; break;
case "cognome":  				$messaggio = "фамилия"; break;
case "nome":  					$messaggio = "име"; break;
case "Dal":  					$messaggio = "От"; break;
case "dal":  					$messaggio = "от"; break;
case "al":  					$messaggio = "до"; break;
case "Tipo di tariffa":  			$messaggio = "Тип тарифа"; break;
case "tariffa":  				$messaggio = "тарифа"; break;
case "sconto":  				$messaggio = "отстъпка"; break;
case "caparra":  				$messaggio = "депозит"; break;
case "se diversa dalla normale":  		$messaggio = "ако е различна от нормалната"; break;
case "nº di persone":  				$messaggio = "брой хора"; break;
case "Nº di piano":  				$messaggio = "Номер на етаж"; break;
case "e/o di casa":  				$messaggio = "и/или номер на сграда"; break;
case "e/o di persone":  			$messaggio = "и/или брой хора"; break;
case "costo aggiuntivo unico":  		$messaggio = "единично допълнително плащана"; break;
case "da moltiplicare per":  			$messaggio = "да се умножи по"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "седмично допълнително плащане"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "дневно допълнително плащане"; break;
case "nº di settimane da applicare":  		$messaggio = "брой седмици за които се отнася"; break;
case "nº di giorni da applicare":  		$messaggio = "брой дни за които се отнася"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "Inserisci la prenotazione":  		$messaggio = "Въведете резервацията"; break;
case "Torna al menù principale":  		$messaggio = "Обратно в главното меню"; break;
case " o spezzarla":  				$messaggio = " или да се разделят"; break;
case "Spezza la prenotazione in":  		$messaggio = "Разделете резервацията на"; break;
case "parti":  					$messaggio = "части"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Не е възможно да се раздели резервацията поради броя на хората"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Не е възможно да се въведе резервацията без"; break;
case "dividerla":  				$messaggio = "да се раздели"; break;
case "in":  					$messaggio = "на"; break;
case "Spezza la prenotazione in":  		$messaggio = "Разделете резервацията на"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Не е възможно да се въведе резервацията за"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "защото междувременно базата данни беше променена"; break;
case "Prenotazione":  				$messaggio = "Резервация"; break;
case "settiman":  				$messaggio = "седмица"; break;
case "giorn":  					$messaggio = "ден"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "за Г-н/Г-жа"; break;
case "per":  					$messaggio = "да"; break;
case "persone":  				$messaggio = "души"; break;
case "Costo unico":  				$messaggio = "Единично плащане"; break;
case "moltiplicato per":  			$messaggio = "умножено по"; break;
case "Costo settimanale":  			$messaggio = "Седмично плащана"; break;
case "Costo giornaliero":  			$messaggio = "Дневно плащане"; break;
case "settimane":  				$messaggio = "седмици"; break;
case "giorni":  				$messaggio = "дни"; break;
case "TOTALE":  				$messaggio = "ОБЩО"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "resto da pagare":  			$messaggio = "остатък за плащане"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "inserita":  				$messaggio = "въведен"; break;
case "Modifica la prenotazione":  		$messaggio = "Променете резервация"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Sconto":  				$messaggio = "Отстъпка"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Нужно е фамилното име"; break;
case "confermata":  				$messaggio = "потвърдена резервация"; break;
case "Confermata":  				$messaggio = "Потвърдена резервация"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Брой резервации от този тип"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Добавете други типове"; break;
case "Tipologia":  				$messaggio = "Тип"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Не е въведена нова резервация"; break;
case "Transazione scaduta":  			$messaggio = "Изтекла транзакция"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Не е възможно да се въведе допълнително плащане към резервацията за"; break;
case "Orario stimato di entrata":  		$messaggio = "Приблизително време на пристигане"; break;
case "giorno":  				$messaggio = "ден"; break;
case "Metodo pagamento caparra":  		$messaggio = "Метод за плащане на депозита"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Заявените в съобщението резултати вече са въведени"; break;
case "Attenzione":  				$messaggio = "Внимание"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "общата цена на въведените резервации"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "общата цена на въведените депозите"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "е различна от тази съдържаща се в съобщението за заявяване на резервация"; break;
case "Origine":  				$messaggio = "Произход"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Внимание</b>: общата цена"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "е различна от отдалечената цена"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inserted reservations as a group"; break;
case "prezzo totale":  				$messaggio = "total price"; break;
case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "resto commissioni":  			$messaggio = "rest of commissions"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Въведете нова резервация"; break;
case "Cliente titolare":  			$messaggio = "Титулярен клиент"; break;
case "cognome":  				$messaggio = "фамилия"; break;
case "nome":  					$messaggio = "име"; break;
case "Dal":  					$messaggio = "От"; break;
case "dal":  					$messaggio = "от"; break;
case "al":  					$messaggio = "до"; break;
case "Tipo di tariffa":  			$messaggio = "Тип тарифа"; break;
case "tariffa":  				$messaggio = "тарифа"; break;
case "sconto":  				$messaggio = "отстъпка"; break;
case "caparra":  				$messaggio = "депозит"; break;
case "se diversa dalla normale":  		$messaggio = "ако е различна от нормалната"; break;
case "nº di persone":  				$messaggio = "брой хора"; break;
case "Nº di piano":  				$messaggio = "Номер на етаж"; break;
case "e/o di casa":  				$messaggio = "и/или номер на сграда"; break;
case "e/o di persone":  			$messaggio = "и/или брой хора"; break;
case "costo aggiuntivo unico":  		$messaggio = "единично допълнително плащана"; break;
case "da moltiplicare per":  			$messaggio = "да се умножи по"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "седмично допълнително плащане"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "дневно допълнително плащане"; break;
case "nº di settimane da applicare":  		$messaggio = "брой седмици за които се отнася"; break;
case "nº di giorni da applicare":  		$messaggio = "брой дни за които се отнася"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "Inserisci la prenotazione":  		$messaggio = "Въведете резервацията"; break;
case "Torna al menù principale":  		$messaggio = "Обратно в главното меню"; break;
case " o spezzarla":  				$messaggio = " или да се разделят"; break;
case "Spezza la prenotazione in":  		$messaggio = "Разделете резервацията на"; break;
case "parti":  					$messaggio = "части"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Не е възможно да се раздели резервацията поради броя на хората"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Не е възможно да се въведе резервацията без"; break;
case "dividerla":  				$messaggio = "да се раздели"; break;
case "in":  					$messaggio = "на"; break;
case "Spezza la prenotazione in":  		$messaggio = "Разделете резервацията на"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Не е възможно да се въведе резервацията за"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "защото междувременно базата данни беше променена"; break;
case "Prenotazione":  				$messaggio = "Резервация"; break;
case "settiman":  				$messaggio = "седмица"; break;
case "giorn":  					$messaggio = "ден"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "за Г-н/Г-жа"; break;
case "per":  					$messaggio = "да"; break;
case "persone":  				$messaggio = "души"; break;
case "Costo unico":  				$messaggio = "Единично плащане"; break;
case "moltiplicato per":  			$messaggio = "умножено по"; break;
case "Costo settimanale":  			$messaggio = "Седмично плащана"; break;
case "Costo giornaliero":  			$messaggio = "Дневно плащане"; break;
case "settimane":  				$messaggio = "седмици"; break;
case "giorni":  				$messaggio = "дни"; break;
case "TOTALE":  				$messaggio = "ОБЩО"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "resto da pagare":  			$messaggio = "остатък за плащане"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "inserita":  				$messaggio = "въведен"; break;
case "Modifica la prenotazione":  		$messaggio = "Променете резервация"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Sconto":  				$messaggio = "Отстъпка"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Нужно е фамилното име"; break;
case "confermata":  				$messaggio = "потвърдена резервация"; break;
case "Confermata":  				$messaggio = "Потвърдена резервация"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Брой резервации от този тип"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Добавете други типове"; break;
case "Tipologia":  				$messaggio = "Тип"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Не е въведена нова резервация"; break;
case "Transazione scaduta":  			$messaggio = "Изтекла транзакция"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Не е възможно да се въведе допълнително плащане към резервацията за"; break;
case "Orario stimato di entrata":  		$messaggio = "Приблизително време на пристигане"; break;
case "giorno":  				$messaggio = "ден"; break;
case "Metodo pagamento caparra":  		$messaggio = "Метод за плащане на депозита"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Заявените в съобщението резултати вече са въведени"; break;
case "Attenzione":  				$messaggio = "Внимание"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "общата цена на въведените резервации"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "общата цена на въведените депозите"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "е различна от тази съдържаща се в съобщението за заявяване на резервация"; break;
case "Origine":  				$messaggio = "Произход"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Внимание</b>: общата цена"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "е различна от отдалечената цена"; break;
case "Prenota":  				$messaggio = "Reserve"; break;
case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inserted reservations as a group"; break;
case "prezzo totale":  				$messaggio = "total price"; break;
case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "resto commissioni":  			$messaggio = "rest of commissions"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "valuta":  				$messaggio = "currency"; break;
case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
case "da":  					$messaggio = "from"; break;
case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
